# The core module

This module contains the Python bindings of the C++ code. The documentation for all the library's classes and functions has been split up in several categories. However, this organisation is only logical, since all the objects described here are contained in the same module and should be accessed as `ba.core.*`.

```eval_rst
.. toctree::
   :maxdepth: 2

   particles.md
   topology.md
   parsers.md
   exporters.md
   filters.md
   trajectories.md
   observables.md
   neighbours.md
   utils.md

```
